@@ -4,7 +4,6 @@ import numpy as np
 from tqdm import tqdm 
 from nltk.tokenize import sent_tokenize, word_tokenize
 
-# NOTE: genbrug kode fra evaluering af model på validering?
 # TODO: add batch_size, num_workers (til dataloader) som args.
 def predict(network = None, 
             sentences = None,
@@ -12,24 +11,27 @@ def predict(network = None,
             transformer_config = None,
             max_len = 128,
             device = None,
-            tag_encoder = None):
+            tag_encoder = None,
+            tag_outside = None,
+            batch_size = 1,
+            num_workers = 1):
 
     # set network to appropriate mode.
     network.eval()
 
-    # fill 'dummy' tags.
+    # fill 'dummy' tags (expected input for dataloader).
     tag_fill = [tag_encoder.classes_[0]]
     tags_dummy = [tag_fill * len(sent) for sent in sentences]
     
-    # TODO: kan vi genbruge fra validation?
-    # TODO: kan vi reducere til danlp-logik?
-    dl = create_dataloader(sentences,
-                           tags_dummy, 
-                           transformer_tokenizer,
-                           transformer_config,
+    dl = create_dataloader(sentences = sentences,
+                           tags = tags_dummy, 
+                           transformer_tokenizer = transformer_tokenizer,
+                           transformer_config = transformer_config,
                            max_len = max_len, 
-                           batch_size = 1, 
-                           tag_encoder = tag_encoder)
+                           batch_size = batch_size, 
+                           tag_encoder = tag_encoder,
+                           tag_outside = tag_outside,
+                           num_workers = num_workers)
 
     predictions = []
     
@@ -55,15 +57,18 @@ def predict(network = None,
 
     return predictions
 
-def predict_text(network = None, 
-                 text = "Ronaldo spiller i Juventus. Han er god.",
-                 transformer_tokenizer = None,
-                 transformer_config = None,
-                 max_len = 128,
-                 device = None,
-                 tag_encoder = None,
-                 sent_tokenizer = sent_tokenize,
-                 word_tokenizer = word_tokenize):
+def predict_text(network, 
+                 text,
+                 transformer_tokenizer,
+                 transformer_config,
+                 max_len,
+                 device,
+                 tag_encoder,
+                 tag_outside,
+                 batch_size = 1,
+                 num_workers = 1,
+                 sent_tokenize = sent_tokenize,
+                 word_tokenize = word_tokenize):
 
     sentences = sent_tokenize(text)
 
@@ -75,9 +80,10 @@ def predict_text(network = None,
                           transformer_config = transformer_config,
                           max_len = max_len,
                           device = device,
-                          tag_encoder = tag_encoder)
+                          batch_size = batch_size,
+                          num_workers = num_workers,
+                          tag_encoder = tag_encoder,
+                          tag_outside = tag_outside)
 
     return sentences, predictions
 
-
-
